/*
 * @(#) checks.h - 0.4 - Charles Mercadal
 *  See license in LICENSE.txt
 */

#ifndef CHECKS_H
#define CHECKS_H


#include <sys/types.h>
#include <sys/stat.h>

#include <ctype.h>
#include <err.h>
#include <signal.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <unistd.h>

/*
 * These constants should be the equivalent of those 
 * used in FreeBSD's sysexit.  I would use sysexit, but 
 * we then limit ourselves to only FreeBSD, so this will 
 * work as an OK solution.
 */
#define eMallocFoobarExit	1	/* malloc() returned NULL */
#define eBadFile		65	/* Can't write checksrc */
#define eBadUserExit		64	/* unknown arguments, etc. */
#define eNoError		0	/* clean return */


/* Struct definition & typedefs */
typedef struct
{
    int		sleepTime;		/* Time to sleep between checking */
    char	minOrSec;		/* Is the timing loop in min or sec */
    char	nrm;			/* Don't warn for removal */
    char	numberOfDirs;	/* How many directories are we checking? */
} pref;

typedef struct
{
    off_t	presentValue;	/* The new value of the dir size */
    char	*directory;		/* Pointer to the name of the directory */
} info;

/* Global constants */
const char PrefFile[]  = "/.checksrc";	/* Preference file name */
const char BadMalloc[] = "MEMORY EXHAUSTED!\a";
const char BadFileIO[] = "Unable to access file ~/.checksrc";

#ifndef lint
const char Copyright[] =
    "@(#) Copyright (c) 2000-2001 Charles Mercadal - All rights reserved";
#endif	/* not LINT */
#endif	/* not CHEKCS_H */
